@@ -2,9 +2,11 @@
 from __future__ import annotations
 
 from sensor_state_data import (
-    DeviceClass,
+    BinarySensorDeviceClass,
+    BinarySensorValue,
     DeviceKey,
     SensorDescription,
+    SensorDeviceClass,
     SensorDeviceInfo,
     SensorUpdate,
     SensorValue,
@@ -13,15 +15,17 @@ from sensor_state_data import (
 
 from .parser import QingpingBluetoothDeviceData
 
-__version__ = "0.0.1"
+__version__ = "0.2.1"
 
 __all__ = [
     "QingpingBluetoothDeviceData",
+    "BinarySensorDeviceClass",
+    "BinarySensorValue",
     "SensorDescription",
     "SensorDeviceInfo",
-    "DeviceClass",
     "DeviceKey",
     "SensorUpdate",
+    "SensorDeviceClass",
     "SensorDeviceInfo",
     "SensorValue",
     "Units",
